/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.metadata.web.resources;

import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.*;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

/**
 * This class provides RESTful API for Types.
 * 
 * A type is the description of any representable item;
 * e.g. a Hive table
 */
@Path("types")
public class TypesResource {

    @POST
    @Path("submit/{type}")
    @Consumes(MediaType.APPLICATION_JSON)
    @Produces(MediaType.APPLICATION_JSON)
    public Response submit(@Context HttpServletRequest request,
                           @PathParam("type") String type) {
        return Response.ok().build();
    }

    @DELETE
    @Path("delete/{type}")
    @Produces(MediaType.APPLICATION_JSON)
    public Response delete(@Context HttpServletRequest request,
                           @PathParam("type") String type) {
        // todo - should this be supported?
        return Response.status(Response.Status.BAD_REQUEST).build();
    }

    @POST
    @Path("update/{type}")
    @Produces(MediaType.APPLICATION_JSON)
    public Response update(@Context HttpServletRequest request,
                            @PathParam("type") String type) {
        return Response.ok().build();
    }
}
